==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/util/XMLJ.h <==
// public final class gnu.xml.libxmlj.util.XMLJ

// class file dependencies
// @dep_class 90acef4361e84575 gnu_xml_libxmlj_util_XMLJ
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_XMLJ_H_
#define _JC_gnu_xml_libxmlj_util_XMLJ_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_javax_xml_transform_Result$object;
struct _jc_javax_xml_transform_Source$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs	_jc_gnu_xml_libxmlj_util_XMLJ$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$refs	_jc_gnu_xml_libxmlj_util_XMLJ$refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$object	_jc_gnu_xml_libxmlj_util_XMLJ$object;

typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct	_jc_gnu_xml_libxmlj_util_XMLJ$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vmethods	_jc_gnu_xml_libxmlj_util_XMLJ$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vtable	_jc_gnu_xml_libxmlj_util_XMLJ$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vtype	_jc_gnu_xml_libxmlj_util_XMLJ$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct {
	jint	LOOKAHEAD;
	jboolean	initialised;
};
extern _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct _jc_gnu_xml_libxmlj_util_XMLJ$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ$object *);

// Static methods
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getAbsoluteURI$ce5c2cce425c6261(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getBaseURI$553ccbca77a96dc0(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_io_InputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$c13734ab39bdedf1(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$3e851a79110ef8aa(_jc_env *, struct _jc_java_net_URL$object *);
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$26ac1ec43ad12ece(_jc_env *, struct _jc_object *);
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$57484e0918fd0bc2(_jc_env *, struct _jc_org_xml_sax_InputSource$object *);
extern struct _jc_java_io_OutputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getOutputStream$1c61aa34b485aebc(_jc_env *, struct _jc_object *);
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$init$d82f2cc8ccf1c754(_jc_env *);
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$xmljGetInputStream$6ed9abf98f075baa(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_XMLJ$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_XMLJ$vmethods	gnu_xml_libxmlj_util_XMLJ;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_XMLJ$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_XMLJ$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ$refs {
    _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs	gnu_xml_libxmlj_util_XMLJ;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs	gnu_xml_libxmlj_util_XMLJ;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$object {
	_jc_gnu_xml_libxmlj_util_XMLJ$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_XMLJ$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_XMLJ$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_XMLJ$vtype _jc_gnu_xml_libxmlj_util_XMLJ$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_XMLJ, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_XMLJ$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_XMLJ_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/util/XMLJ.h <==
// public final class gnu.xml.libxmlj.util.XMLJ

// class file dependencies
// @dep_class 90acef4361e84575 gnu_xml_libxmlj_util_XMLJ
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_XMLJ_H_
#define _JC_gnu_xml_libxmlj_util_XMLJ_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_javax_xml_transform_Result$object;
struct _jc_javax_xml_transform_Source$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs	_jc_gnu_xml_libxmlj_util_XMLJ$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$refs	_jc_gnu_xml_libxmlj_util_XMLJ$refs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$nonrefs	_jc_gnu_xml_libxmlj_util_XMLJ$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$object	_jc_gnu_xml_libxmlj_util_XMLJ$object;

typedef struct _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct	_jc_gnu_xml_libxmlj_util_XMLJ$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vmethods	_jc_gnu_xml_libxmlj_util_XMLJ$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vtable	_jc_gnu_xml_libxmlj_util_XMLJ$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_XMLJ$vtype	_jc_gnu_xml_libxmlj_util_XMLJ$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct {
	jint	LOOKAHEAD;
	jboolean	initialised;
};
extern _jc_gnu_xml_libxmlj_util_XMLJ$fields_struct _jc_gnu_xml_libxmlj_util_XMLJ$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_XMLJ$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getAbsoluteURI$ce5c2cce425c6261(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getBaseURI$553ccbca77a96dc0(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$c13734ab39bdedf1(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$3e851a79110ef8aa(_jc_env *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$26ac1ec43ad12ece(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getInputStream$57484e0918fd0bc2(_jc_env *, struct _jc_org_xml_sax_InputSource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$getOutputStream$1c61aa34b485aebc(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_util_XMLJ$method$init$d82f2cc8ccf1c754(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_libxmlj_util_NamedInputStream$object *_jc_gnu_xml_libxmlj_util_XMLJ$method$xmljGetInputStream$6ed9abf98f075baa(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_XMLJ$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_XMLJ$vmethods	gnu_xml_libxmlj_util_XMLJ;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_XMLJ$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_XMLJ$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ$refs {
    _jc_gnu_xml_libxmlj_util_XMLJ$sub_refs	gnu_xml_libxmlj_util_XMLJ;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_XMLJ$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_XMLJ$sub_nonrefs	gnu_xml_libxmlj_util_XMLJ;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_XMLJ$object {
	_jc_gnu_xml_libxmlj_util_XMLJ$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_XMLJ$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_XMLJ$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_XMLJ$vtype _jc_gnu_xml_libxmlj_util_XMLJ$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_XMLJ, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_XMLJ$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_XMLJ_H_ */
